/*
 * Copyright 2016 - 2025 Gary Talent (gary@drinkingtea.net). All rights reserved.
 */

#include "makecopypopup.hpp"

namespace studio {

ox::Error MakeCopyPopup::open(ox::StringViewCR path) noexcept {
	m_stage = Stage::Opening;
	OX_REQUIRE(idx, ox::findIdx(path.rbegin(), path.rend(), '/'));
	m_srcPath = path;
	m_dirPath = substr(path, 0, idx + 1);
	m_title = sfmt("Copy {}", path);
	m_fileName = "";
	return {};
}

void MakeCopyPopup::close() noexcept {
	m_stage = Stage::Closed;
	m_open = false;
}

bool MakeCopyPopup::isOpen() const noexcept {
	return m_open;
}

void MakeCopyPopup::draw(StudioContext const &ctx, ImVec2 const &sz) noexcept {
	switch (m_stage) {
		case Stage::Closed:
			break;
		case Stage::Opening:
			ImGui::OpenPopup(m_title.c_str());
			m_stage = Stage::Open;
			m_open = true;
		[[fallthrough]];
		case Stage::Open:
			ig::centerNextWindow(ctx.tctx);
			ImGui::SetNextWindowSize(sz);
			constexpr auto modalFlags = ImGuiWindowFlags_NoCollapse | ImGuiWindowFlags_NoMove | ImGuiWindowFlags_NoResize;
			if (ImGui::BeginPopupModal(m_title.c_str(), &m_open, modalFlags)) {
				if (ImGui::IsWindowAppearing()) {
					ImGui::SetKeyboardFocusHere();
				}
				ig::InputText("Name", m_fileName);
				bool open = true;
				switch (ig::PopupControlsOkCancel(open)) {
					case ig::PopupResponse::None:
						break;
					case ig::PopupResponse::OK:
						{
							auto const p = sfmt("{}{}", m_dirPath, m_fileName);
							if (!ctx.project->exists(p)) {
								makeCopy.emit(m_srcPath, p);
								close();
							}
						}
						break;
					case ig::PopupResponse::Cancel:
						close();
						break;
				}
				ImGui::EndPopup();
			}
			break;
	}
}


}